@@ -58,7 +58,7 @@ class CLI(cl1.CLI):
 			if self.arguments.present(['--info']):
 				response = netw0rk.network.info()
 				r3sponse.log(response=response)
-				if r3sponse.success(response): 
+				if response.success: 
 					del response["message"] ; del response["error"] ; del response["success"]
 					info = json.dumps(response, indent=0).replace("{\n","").replace("\n}","").replace('",',"").replace('"',"")
 					print(info)
@@ -77,7 +77,7 @@ class CLI(cl1.CLI):
 			if self.arguments.present(['--info']):
 				response = netw0rk.firewall.info()
 				r3sponse.log(response=response)
-				if r3sponse.success(response): 
+				if response.success: 
 					del response["message"] ; del response["error"] ; del response["success"]
 					info = json.dumps(response, indent=0).replace("{\n","").replace("\n}","").replace('",',"").replace('"',"")
 					print(info)
